<?php
namespace PME\Controllers\Custo;

use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;

  class DesvioConsumoController extends \Zeedhi\Framework\Controller\Report {
    protected $birtStrategy;
    protected $newCode;
    protected $lista;
    protected $connection;
    protected $ConsumoPlanejadoRealizadoController;
    protected $CustoPlanejadoRealizadoController;
    protected $utilities;

    public function __construct(ReportService $reportService, $birtStrategy, $newCode, $lista, $connection, $ConsumoPlanejadoRealizadoController, $CustoPlanejadoRealizadoController, $utilities) {
      parent::__construct($reportService);
      $this->birtStrategy  = $birtStrategy;
      $this->newCode       = $newCode;
      $this->lista         = $lista;
      $this->connection    = $connection;
      $this->ConsumoPlanejadoRealizadoController = $ConsumoPlanejadoRealizadoController;
      $this->CustoPlanejadoRealizadoController = $CustoPlanejadoRealizadoController;
      $this->utilities     = $utilities;
    }

    protected $reportMapping = array (
      'PME01600' => 
      array (
        'strategy' => 'BIRT',
        'parameterMapping' => 
        array (
          "CDTIPOCUSTO"   => "P_NRTIPOCUSTO",
          "TAMACNIVEL"    => "P_NRTAMACNIVEL",
          "ORDENA"        => "P_NRTAMCODIGO",
          "CDFILCENTPME"  => "P_CDFILCENTPME",
          "NRCONSPLAN"    => "P_NRCONSPLAN",
          "LISTASERV"     => "P_NRLISTASERVICO", 
          "PRODINICIAL"   => "P_CDPRODINIC",
          "PRODFINAL"     => "P_CDPRODFINA",
          "ESTOCAVEIS"    => "P_IDESTOCAVEIS",
          "DTMESINIC"     => "P_DTMESINIC",
          "DTMESFINA"     => "P_DTMESFINA",
          "NAOESTOCAVEIS" => "P_IDNESTOCAVEIS",
          "DTDE"          => "P_DTINICIAL",
          "DTATE"         => "P_DTFINAL",
          "NMTIPOCUSTO"   => "P_NMTIPOCUSTO",
          "CDPICTPROD"    => "P_CDPICTPROD",
          "DIFQTD"        => "P_IDDIFERENCA",
          "AGRUPMASK"     => "P_MASCAGRUP",
          "NRORG"         => "P_NRORG"
        )
      ),
      'PME01601' => 
      array (
        'strategy' => 'BIRT',
        'parameterMapping' => 
        array (
          "CDTIPOCUSTO"   => "P_NRTIPOCUSTO",
          "TAMACNIVEL"    => "P_NRTAMACNIVEL",
          "ORDENA"        => "P_NRTAMCODIGO",
          "DTDE"          => "P_DTINICIAL",
          "DTATE"         => "P_DTFINAL",
          "LISTASERV"     => "P_NRLISTASERVICO", 
          "CDFILCENTPME"  => "P_CDFILCENTPME",
          "NRCONSPLAN"    => "P_NRCONSPLAN",
          "PRODINICIAL"   => "P_CDPRODINIC",
          "PRODFINAL"     => "P_CDPRODFINA",
          "ESTOCAVEIS"    => "P_IDESTOCAVEIS",
          "DTMESINIC"     => "P_DTMESINIC",
          "DTMESFINA"     => "P_DTMESFINA",
          "NAOESTOCAVEIS" => "P_IDNESTOCAVEIS",
          "DIFQTD"        => "P_IDDIFERENCA",
          "AGRUPMASK"     => "P_MASCAGRUP",
          "CDPICTPROD"    => "P_CDPICTPROD",
          "NMTIPOCUSTO"   => "P_NMTIPOCUSTO",
          "NRORG"         => "P_NRORG"
        )
      )
    );
    
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
      $rows = $request->getRow();
      $nrorg = $this->utilities->getNrOrg();
      
      $rows['NRORG'] = $nrorg;
      $rows['NRCONSPLAN'] = $this->newCode->getCodeByTableName('CONSPLAN'.$rows['CDFILCENTPME'], $nrorg);
      
      $unidadeServico = [];
      foreach($rows['SERVICO'] as $row){
        $concatUnidServ = $row['FILISERV'];
        array_push($unidadeServico, $concatUnidServ);
      }
      
      $servicos = [];
      foreach($rows['SERVICO'] as $row){
        $concatServ = $row['CDSERVFILI'];
        array_push($servicos, $concatServ);
      }
      
      if ($rows['GRUPFILI'] == NULL) {
        if (empty($rows['CDFILIAL'])) {
          $unidade = null;
          $rows['CDFILIAL'] = $this->ConsumoPlanejadoRealizadoController->getUnidades($rows);
        } else {
          $rows['CDFILIAL'] = is_array($rows['CDFILIAL']) ? join("_", $rows['CDFILIAL']) : $rows['CDFILIAL'];
          $unidade = $rows['CDFILIAL'];
        }
      } else {
        if (empty($rows['CDFILIAL'])) $rows['CDFILIAL'] = $rows['CDFILIAL'] = $this->ConsumoPlanejadoRealizadoController->getUnidadesGrupoServ($rows, $nrorg);  
        else $rows['CDFILIAL'] = is_array($rows['CDFILIAL']) ? join("_", $rows['CDFILIAL']) : $rows['CDFILIAL'];
        $unidade = $rows['CDFILIAL'];
      }
      
      //$rows['LISTAFILI'] = $this->lista->geraLista($rows['CDFILIAL'], $rows['NRORG']);
      $rows['LISTASERV'] = $this->CustoPlanejadoRealizadoController->geraListaServico($rows, $nrorg);
      
      if($rows['ORDENA'] == 0) $rows['TAMCODIGO'] = 10;
      else $rows['TAMCODIGO'] = 0;
      
      $cdprodIni = $rows['PRODINICIAL']['CDARVPROD'] ? $rows['PRODINICIAL']['CDARVPROD'] : 0;
      if(empty($rows['PRODFINAL']['CDARVPROD'])) $cdprodFin = 'zzzzzzzzzzz';
      else $cdprodFin = str_pad($rows['PRODFINAL']['CDARVPROD'], 10, 'z');
  
      $rows['PRODINICIAL'] = $cdprodIni;
      $rows['PRODFINAL'] = $cdprodFin;
      
      $this->ConsumoPlanejadoRealizadoController->procedure($rows);
      $this->birtStrategy->setReportLocale($this->utilities->getLanguage());
      $this->birtStrategy->setReportFormat(strtolower($rows['reportFormat']));
    }
    
    public function getServicos($rows){
      $nrorg = $this->utilities->getNrOrg();
      $servicos = [];
      
      if (empty($rows['GRUPOSERVICO'])) $rows['GRUPOSERVICO'] = 'T';
      if (empty($rows['CDGRUPFILI'])) $rows['CDGRUPFILI'] = 'T';
      
      if(is_array($rows['GRUPOSERVICO'])) $grupServ = join("_", $rows['GRUPOSERVICO']);
      else $grupServ = $rows['GRUPOSERVICO'];
      
      $query = "SELECT DISTINCT S.CDSERVFILI, S.NMSERVICO, S.NRORG FROM SERVICO      S, FILGRUPFILI  F, FILIAL       FI WHERE ( S.CDFILIAL = F.CDFILIAL (+) ) AND ( FI.CDFILIAL = S.CDFILIAL ) AND ( ( INSTR(:CDFILIAL, S.CDFILIAL) <> 0 ) OR ( :CDFILIAL = 'T' ) ) AND ( ( INSTR(:CDGRUPSERV, S.CDGRUPSERV) <> 0 ) OR ( :CDGRUPSERV = 'T' ) ) AND ( ( INSTR(:CDGRUPFILI, F.CDGRUPFILI) <> 0 ) OR ( :CDGRUPFILI = 'T' ) ) AND ( FI.CDFILCENTPME = :CDFILCENTPME ) ORDER BY S.CDSERVFILI";
      $params = array(
        "CDFILCENTPME" => $rows["CDFILCENTPME"],
        "CDGRUPFILI"   => $rows['CDGRUPFILI'],
        "CDFILIAL"     => $rows['CDFILIAL'],
        "CDGRUPSERV"   => $grupServ
      );
      $stmt = $this->connection->prepare($query);
      $stmt->execute($params);
      $result = $stmt->fetchAll();
      
      foreach($result as $row){
        array_push($servicos, $row['CDSERVFILI']);
      }
      $resultadoServ = join("_", $servicos);
      return $resultadoServ;
    }
  }