import {
  Config, Metadata, Loader, Http, IEventParam, IDictionary,
} from '@zeedhi/core';
import {
  Select, GridEditable, Form, Button,
} from '@zeedhi/common';
import { PmeMask } from '@/config';

export class Pme11000PercentualAdesaoPratoController {
  private utilities = Loader.getInstance('Utilities');
  
  public appController = Loader.getInstance('AppController');
  
  public gridEditableController = Loader.getInstance('GridEditableController');
  
  public filterTipoCardapio() {
    const unidade = Metadata.getInstance<Select>('UNIDADE_AGREGADA').value;
    const cardapio = Metadata.getInstance<Select>('TPCARD');
    const cdfilcentpme = this.appController.getCdCentral();
    const conditions = [
      {
        name: 'CDFILIAL',
        operator: '=',
        value: unidade,
      },
      {
        name: 'CDFILCENTPME',
        operator: '=',
        value: cdfilcentpme,
      },
      {
        name: 'NRPASTATCARD',
        operator: '=',
        value: 'T',
      },
    ];
    cardapio.datasource.filter = conditions;
    cardapio.datasource.get();
    this.reloadPercAct();
  }
  
  private reloadPercAct() {
    const cardapio = Metadata.getInstance<Select>('TPCARD');
    if (cardapio.datasource.data.length > 0) {
      this.filterPercAceit(); //  cardapio.datasource.data[0] como argumento
    }
  }
  
  public filterAgregada({ component }: IEventParam<Select>) {
    const grid = Metadata.getInstance<GridEditable>('PERACEITPRATO');
    component.datasource.filter = [
      {
        name: 'CDFILCENTPME',
        operator: '=',
        value: this.appController.getCdCentral(),
      },
    ];
    component.datasource.get();
    grid.datasource.updateData([]);
    grid.datasource.total = 0;
  }
  
  public changeUnidade() {
    const tipoCard = Metadata.getInstance<Select>('TPCARD');
    tipoCard.setValue('');
  }
  
  public reloadGridPerAceitaPrato({ component }: IEventParam<Button>) {
    const form = Metadata.getInstance<Form>('formFilter');
    
    if (form.validate()) {
      this.gridEditableController.reload({ component });
    }
  }
  
  public verifyPratIni({ component }: IEventParam<Select>) {
    const form = Metadata.getInstance<Form>('formFilter');
    if (component.value !== null) {
      if (this.utilities.returnPrat(form.getChildInstance<Select>('PRATO_INICIAL').value, component.value)) {
        this.utilities.showAlert('Alert', 'pme::pratoIniMaior', 'error');
        component.setValue(null);
      }
      this.reloadPercAct();
    }
  }
  
  public controllPratoIni() {
    const pratoFinal = Metadata.getInstance<Select>('PRATO_FINAL');
    if (pratoFinal.value !== null) pratoFinal.setValue(null);
    
    this.reloadPercAct();
  }
  
  public filterPercAceit() {
    const unidade = Metadata.getInstance<Select>('UNIDADE_AGREGADA').value;
    const percPrato: GridEditable = Metadata.getInstance('PERACEITPRATO');
    const pratoIncial = Metadata.getInstance<Select>('PRATO_INICIAL').value;
    const pratoFinal = Metadata.getInstance<Select>('PRATO_FINAL').value;
    const tipoCard = Metadata.getInstance<Select>('TPCARD').selectValue;
    const nivelMaxPlate = (Config.masks.plateMask as PmeMask).nivelMax;
    const form = Metadata.getInstance<Form>('formFilter').value;
    if (form.TPCARD) {
      const conditions = [
        {
          name: 'CDFILIAL',
          operator: '=',
          value: unidade,
        },
        {
          name: 'CDFILCENTPME',
          operator: '=',
          value: this.appController.getCdCentral(),
        },
        {
          name: 'CDPRATOINI',
          operator: '=',
          value: pratoIncial !== null ? pratoIncial : '0',
        },
        {
          name: 'CDPRATOFIN',
          operator: '=',
          value: pratoFinal !== null ? `${pratoFinal}Z` : 'Z',
        },
        {
          name: 'CDTIPOCARD',
          operator: '=',
          value: tipoCard.CDTIPOCARD,
        },
        {
          name: 'MAXCDNVPRATO',
          operator: '=',
          value: nivelMaxPlate,
        },
      ];
      percPrato.datasource.filter = conditions;
      percPrato.datasource.get();
    }
  }
  
  public dataSourceGet({ component }: IEventParam<Select>) {
    component.datasource.get();
  }
  
  public savePercAceita() {
    const grid: GridEditable = Metadata.getInstance('PERACEITPRATO');
    const editedRows = grid.getEditedRows();
    this.checkCentralNull(editedRows);
    
    if (editedRows.length > 0) {
      if (grid) grid.datasource.loading = true;
      Http.post('/percAceita/save', { requestType: 'Row', editedRows }).then((response) => {
        if (response.data.dataset.save[0]) {
          this.gridEditableController.cancelEditedRows({ component: grid });
          grid.datasource.get();
          this.utilities.showAlert('Alert', 'pme::salvoComSucesso', 'success');
        }
      }).finally(() => {
        if (grid) grid.datasource.loading = false;
      });
    }
  }
  
  private checkCentralNull(editedRows: IDictionary) {
    const centralNull = editedRows.filter((data: IDictionary) => data.CDFILCENTPME === null);
    
    if (centralNull.length > 0) {
      centralNull.forEach((row: IDictionary) => {
        row.CDFILCENTPME = this.appController.getCdCentral();
        row.CDFILIAL = Metadata.getInstance<Select>('UNIDADE_AGREGADA').value;
        row.__is_new = true;
      });
    }
  }
  
  public cancelEditingTelaPercentual({ component }: IDictionary) {
    this.gridEditableController.cancelEditing({ component });
  }
}
